@@ -12,7 +12,9 @@
 # Description:
 # ****************************************************************
 from oasis.tasks.load_products import load_products
+from oasis.tasks.sync_document_types import sync_document_types
 
 __all__ = [
-    "load_products"
+    "load_products",
+    "sync_document_types"
 ]
